
[![](https://codecov.io/gh/nickderobertis/py-file-conf-gui/branch/master/graph/badge.svg)](https://codecov.io/gh/nickderobertis/py-file-conf-gui)

# py-file-conf-gui

## Overview

Web GUI for pyfileconf

## Getting Started

Install `py-file-conf-gui`:

```
pip install py-file-conf-gui
```

A simple example:

```python
import pyfileconfgui

# Do something with pyfileconfgui
```

## Links

See the
[documentation here.](
https://nickderobertis.github.io/py-file-conf-gui/
)

## Author

Created by Nick DeRobertis. MIT License.